function X = ucentroid(dp)
%UCENTROID Centroid for belief distribution over utility measures.
%   X = UCENTROID(dp) returns the centroid for the belief distribution
%   over the utility measures of the given decision problem.
%
%   See also PCENTROID.
  
  X = [];
  for n = 1:length(dp.A)
    for m = 1:length(dp.A(n).C)
      X = [X; umean(dp.A(n).C(m))];
    end
  end
  
  
function x = umean(c)
%UMEAN Mean for local belief distribution over utility measure.
%   x = UMEAN(c) returns the mean for the belief distribution over the
%   utility measure of the given consequence.
%
%   If the belief distribution does not contain a variable, then it is
%   interpreted as a constant specifying the mean of the belief
%   distribution.
  
  if isempty(findstr(c.udist, 'x'))
    x = str2num(c.udist);
  else
    x = quad8(inline(strcat('x.*(', c.udist, ')')), 0, 1);
  end